@@ -3,7 +3,7 @@ from .get_bd import get_bd
 from .get_gps import get_gps
 from .get_mlsv import logmean, get_MLSv, ncToPiv2D
 from .get_Sv import get_Sv, get_active_dives
-from .help_fun import haversine, compute_c, alpha_FrancoisGarrison, tvg
+from .help_fun import haversine, compute_c, alpha_FrancoisGarrison, tvg, absorption
 from .kml2 import get_kml_track
 from .log_update import getSatFile, sat2log
 from .meta_reader import raw2meta_extract
